@@ -3,14 +3,13 @@ release_questions <- function() {
     "Is the code free of #TODOs?",
     "Have you updated REFERENCES.bib with a citation to the published study?",
     "Have you updated inst/CITATION with a citation to the published study?",
-    "Have you updated the version number in inst/CITATION, NEWS and DESCRIPTION?",
-    "Have you updated .zenodo.json?"
+    "Have you updated the version number in inst/CITATION, NEWS and DESCRIPTION?"
   )
 }
 
 # Additional tests:
 # 
 # check_win_devel(); check_rhub()
-# revdepcheck()
+# revdepcheck::revdep_check()
 # build_vignettes()
 # 
\ No newline at end of file
